@@ -7,13 +7,13 @@ test_that("twoClassSummary is calculating correctly", {
   tr_dat <- twoClassSim(100)
   te_dat <- twoClassSim(100)
   mod <- knn3(x = as.matrix(tr_dat[, 1:5]), y = tr_dat$Class)
-  te_pred <- predict(mod, tr_dat[, 1:5], type = "class")
-  te_prob <- predict(mod, tr_dat[, 1:5], type = "prob")
+  te_pred <- predict(mod, te_dat[, 1:5], type = "class")
+  te_prob <- predict(mod, te_dat[, 1:5], type = "prob")
   te_prob <- as.data.frame(te_prob)
 
   cm <- caret::confusionMatrix(te_pred, te_dat$Class)
   library(pROC)
-  roc_crv <- pROC::roc(te_dat$Class, te_prob$Class1, direction = ">")
+  roc_crv <- pROC::roc(te_dat$Class, te_prob$Class1, direction = ">", quiet = TRUE)
   roc_auc <- as.numeric(pROC::auc(roc_crv))
 
   te_res <- te_prob
